Commit 263efc60 authored by Andrey Filippov's avatar Andrey Filippov
Browse files

debugging geometry correction, testing disp_dist

parent b9ca98e0
Loading
Loading
Loading
Loading
+3 −3
Original line number Diff line number Diff line
@@ -363,7 +363,7 @@ extern "C" __global__ void get_tiles_offsets(
			(extrinsic_corr.imu_move[1] != 0.0) ||
			(extrinsic_corr.imu_move[2] != 0.0);
// Temporary
	imu_exists = 0;
//	imu_exists = 0;
#ifdef DEBUG21
	if ((ncam == DBG_CAM)  && (task_num == DBG_TILE)){
		printf("\nTile = %d, camera= %d\n", task_num, ncam);
@@ -660,7 +660,7 @@ extern "C" __global__ void get_tiles_offsets(
				dpYci_dtilt * extrinsic_corr.imu_rot[0] +
				dpYci_dazimuth * extrinsic_corr.imu_rot[1] +
				dpYci_droll * extrinsic_corr.imu_rot[2]);
#ifdef DEBUG210
#ifdef DEBUG21
		if ((ncam == DBG_CAM)  && (task_num == DBG_TILE)){
			printf("delta_t = %f,  ers_Xci = %f,  ers_Yci = %f\n", delta_t, ers_Xci, ers_Yci);
		}
@@ -683,7 +683,7 @@ extern "C" __global__ void get_tiles_offsets(
			pXY[0] +=  ers_Xci * rD2rND; // added correction to pixel X
			pXY[1] +=  ers_Yci * rD2rND; // added correction to pixel Y

#ifdef DEBUG210
#ifdef DEBUG21
			if ((ncam == DBG_CAM)  && (task_num == DBG_TILE)){
				printf("k = %f,  wdisparity = %f,  dwdisp_dz = %f\n", k, wdisparity, dwdisp_dz);
				printf("dpXci_pYci_imu_lin[0][0] = %f,  dpXci_pYci_imu_lin[0][2] = %f\n", dpXci_pYci_imu_lin[0][0],dpXci_pYci_imu_lin[0][2]);
+3 −2
Original line number Diff line number Diff line
@@ -74,7 +74,7 @@

#define THREADS_DYNAMIC_BITS           5 // treads in block for CDP creation of the texture list

#define DBG_DISPARITY                  0.0 // 56.0 // disparity for which to calculate offsets (not needed in Java)
#define DBG_DISPARITY               56.0//   0.0 // 56.0 // disparity for which to calculate offsets (not needed in Java)
#define RBYRDIST_LEN                5001   // for doubles 10001 - floats   // length of rByRDist to allocate shared memory
#define RBYRDIST_STEP                  0.0004 // for doubles, 0.0002 - floats // to fit into GPU shared memory (was 0.001);
#define TILES_PER_BLOCK_GEOM          (32/NUM_CAMS)   // each tile has NUM_CAMS threads
@@ -125,7 +125,8 @@
//#define DEBUG20 1

#if (DBG_TILE_X >= 0) && (DBG_TILE_Y >= 0)
//#define DEBUG21 1 // Geometry Correction
#define DEBUG21 1 // Geometry Correction
//#define DEBUG210 1

//#define DEBUG22 1
//#define DEBUG23 1